@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/python22
 #
 # Copyright (c) 2015 Red Hat, Inc. <http://www.redhat.com>
 # This file is part of GlusterFS.
@@ -575,8 +575,13 @@ def get_selinux_status():
     getenforce_cli = ["getenforce"]
     log.debug("Running command '%s'", " ".join(getenforce_cli))
 
-    p1 = subprocess.Popen(getenforce_cli, stdout=subprocess.PIPE,
-                          stderr=subprocess.PIPE)
+    try:
+        p1 = subprocess.Popen(getenforce_cli, stdout=subprocess.PIPE,
+                              stderr=subprocess.PIPE)
+    except OSError as oserr:
+        log.error("Failed to run the command \"getenforce\". Error: %s" %\
+                  oserr)
+        return -1
 
     output, err = p1.communicate()
     rv = p1.returncode
